@@ -14,7 +14,9 @@ sequence, do the following:
 
  1. Find all SAM files in the indicated directory and convert them
     into BAM. These must end in one of the extensions ".sam" or ".sam.gz".
-    A series of <base>.bam files will be created.
+    A series of <base>.bam files will be created. This step will be
+    skipped if SAM files are absent or the corresponding BAM files
+    are already present.
 
  2. Sort the newly created BAM files, creating a series of files named
     <base>_sorted.bam.
@@ -35,13 +37,18 @@ Unless the Fasta file is explicitly provided, this script will look in
 the designated directory for ONE .fa file to use.
 
 Note that you will need temporary space in the directory equivalent to
-the size of the largest SAM file being processed. In addition, you
-should have a copy of the bedGraphToBigWig executable somewhere on
-your path (obtainable in binary form from
-http://hgdownload.cse.ucsc.edu/admin/exe or source form from
-http;//hgdownload.cse.ucsc.edu/admin/jksrc.zip). If the binary is not
-found, this script will use its built-in BigWig loader, which uses a
-lot of RAM.
+the size of the largest SAM file being processed.
+
+This script takes a long time to run and uses significant amounts of
+RAM when generating the coverage graphs. To improve both performance
+and memory consumption, you can install the following C binaries:
+
+  bedGraphToBigWig  -- download from http://hgdownload.cse.ucsc.edu/admin/exe
+                       or build from source downloadable from
+                       http;//hgdownload.cse.ucsc.edu/admin/jksrc.zip
+  genomeCoverageBed -- download from http://code.google.com/p/bedtools/
+
+Place these executables into your path, e.g. /usr/local/bin or ~/bin.
 USAGE
     ;
 
