@@ -1,6 +1,6 @@
 package Bio::DB::Bam::AlignWrapper;
 
-# $Id: AlignWrapper.pm 23933 2010-10-08 14:11:40Z malcook $
+# $Id: AlignWrapper.pm 24231 2010-11-23 22:20:26Z lstein $
 
 =head1 NAME
 
@@ -125,9 +125,6 @@ sub split_splices {
 							  -seq_id => $self->seq_id,
 							  -strand => +1,
 							  -seq    => [$self,$start+$skip,$end-$start], # deferred rendering
-#							  -seq    => substr($self->dna,
-#									    $start+$skip,
-#									    $end-$start),
 							  -type   => $self->type);
 
 	    # in case sequence is missing?
@@ -159,6 +156,18 @@ sub expand_flags {
     shift->{sam}->expand_flags(@_);
 }
 
+sub query {
+    my $self = shift;
+    return Bio::DB::Bam::Query->new($self);
+}
+
+sub target {
+    my $self = shift;
+    return Bio::DB::Bam::Target->new($self);
+}
+
+sub hit { shift->target(@_); }
+
 sub seq_id {
     my $self = shift;
     my $tid  = $self->tid;
